﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.InteropServices;
using System.Runtime.Serialization.Formatters.Binary;
using System.IO;

namespace ClassLibrary1
{
    [Serializable]
    public class LaboratoryObservable : ObservableCollection<Equipment>
    {
        private string nameLab;
        public string NameLab
        {
            get { return nameLab; }
            set
            {
                nameLab = value;
                OnPropertyChanged(new PropertyChangedEventArgs("NameLab"));
            }
        }

        private DateTime dateLab;
        public DateTime DateLab
        {
            get { return dateLab; }
            set
            {
                dateLab = value;
                OnPropertyChanged(new PropertyChangedEventArgs("DateLab"));
            }
        }

        public int oldest
        {
            get
            {
                int old = 0;
                foreach(var x in this)
                {
                    if (x != null)
                    {
                        if (old == 0 || x.year < old)
                            old = x.year;                        
                    }
                }
                return old;
            }
        }


        private bool chang = false;
        public bool IsChanged
        {
            get { return chang; }
            set
            {
                chang = value;
                OnPropertyChanged(new PropertyChangedEventArgs("IsChanged"));
            }
        }

        public LaboratoryObservable()
        {
            CollectionChanged += LaboratoryObservable_CollectionChanged;
            //AddDefaultComputer();
            //AddDefaultPrinter();
            //IsChanged = false;
        }

        private void LaboratoryObservable_CollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {            
            IsChanged = true;
        }

        public void Remove_At(int index)
        {
            base.RemoveAt(index);
            OnPropertyChanged(new PropertyChangedEventArgs("oldest"));
        }

        public void AddDefaultPrinter()
        {
            base.Add(new Printer(new Equipment(), PrinterType.Ink, true));
            base.Add(new Printer(new Equipment("IBM", 2040, "1"), PrinterType.Laser, true));
            OnPropertyChanged(new PropertyChangedEventArgs("oldest"));
        }        

        public void AddDefaultComputer()
        {
            base.Add(new Computer(new Equipment(), ComputerType.Desktop, 2));
            OnPropertyChanged(new PropertyChangedEventArgs("oldest"));
        }

        public void AddCustomComputer(Computer computer)
        {
            base.Add(computer);
            OnPropertyChanged(new PropertyChangedEventArgs("oldest"));
        }

        public bool Computers(object item)
        {
            Computer t = item as Computer;
            if (t != null)
                return true;
            else
                return false;
        }

        public bool Printers(object item)
        {
            Printer t = item as Printer;
            if (t != null)
                return true;
            else
                return false;
        }

        public static bool Save(string filename, LaboratoryObservable labObs)
        {
            FileStream fs = null;
            bool res = false;
            try
            {
                fs = File.Create(filename);
                BinaryFormatter bf = new BinaryFormatter();
                bf.Serialize(fs, labObs);
                res = true;
            }
            catch (Exception ex)
            {
                Console.WriteLine("Исключение " + ex.Message);
            }
            finally
            {
                if (fs != null) fs.Close();
            }
            return res;
        }

        public static bool Load(string filename, ref LaboratoryObservable labObs)
        {
            bool res = false;
            FileStream fs = null;
            try
            {
                fs = File.OpenRead(filename);
                BinaryFormatter bf = new BinaryFormatter();
                var t = bf.Deserialize(fs);
                labObs = t as LaboratoryObservable;
                

                labObs.CollectionChanged += labObs.LaboratoryObservable_CollectionChanged;

                res = true;
            }            
            catch (ArgumentNullException ex)
            {
                Console.WriteLine("Исключение " + ex.Message);
            }
            catch (System.Runtime.Serialization.SerializationException ex)
            {
                Console.WriteLine("Исключение " + ex.Message);
            }
            catch (System.Security.SecurityException ex)
            {
                Console.WriteLine("Исключение " + ex.Message);
            }
            catch (Exception ex)
            {
                Console.WriteLine("Исключение " + ex.Message);
            }
            finally
            {
                if (fs != null) fs.Close();
            }
            return res;
        }      

        public override string ToString()
        {
            return base.ToString();
        }
    }
}
