﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Microsoft.Win32;
using ClassLibrary1;

namespace WPF
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private LaboratoryObservable labObs = new LaboratoryObservable();
        private Computer com = new Computer();

        public MainWindow()
        {
            InitializeComponent();
            DataContext = labObs;
            Grid_new_Computer.DataContext = com;

            ListCollectionView collection_computer = new ListCollectionView(labObs);
            collection_computer.Filter = labObs.Computers;
            comp.ItemsSource = collection_computer;

            ListCollectionView collection_printer = new ListCollectionView(labObs);
            collection_printer.Filter = labObs.Printers;
            print.ItemsSource = collection_printer;

            Binding bd1 = new Binding();
            bd1.Source = print.ItemsSource;
            bd1.Path = new PropertyPath("type");
            TypePrint.SetBinding(TextBlock.TextProperty, bd1);

            Binding bd2 = new Binding();
            bd2.Source = print.ItemsSource;
            bd2.Path = new PropertyPath("year");
            Year.SetBinding(TextBlock.TextProperty, bd2);
        }
        
        private void MenuItem_Add_Default_Printer_Click(object sender, RoutedEventArgs e)
        {
            labObs.AddDefaultPrinter();
        }

        private void MenuItem_Add_Default_Computer_Click(object sender, RoutedEventArgs e)
        {
            labObs.AddDefaultComputer();
        }

        private void MenuItem_Add_Custom_Computer_Click(object sender, RoutedEventArgs e)
        {
            labObs.AddCustomComputer(com);
        }

        private void MenuItem_Remove_Click(object sender, RoutedEventArgs e)
        {
            labObs.Remove_At(allCollec.SelectedIndex);
        }

        private void Grid_Loaded(object sender, RoutedEventArgs e)
        {
            TypeComp.ItemsSource = Enum.GetValues(typeof(ComputerType));
        }

        private void RadioButton_Click(object sender, RoutedEventArgs e)
        {
            if (allCollec.ItemTemplate == null)
            {
                DataTemplate dataTemp = TryFindResource("dataTemp") as DataTemplate;
                allCollec.ItemTemplate = dataTemp;
            }
            else
            {
                allCollec.ItemTemplate = null;
            }
        }

        private void st_obs_TextChanged(object sender, TextChangedEventArgs e)
        {
            labObs.IsChanged = true;
        }

        private void MenuItem_New_Click(object sender, RoutedEventArgs e)
        {
            if(labObs.IsChanged==true)
            {
                MessageBoxResult res = MessageBox.Show("Сохранить изменения?", "Выбор", MessageBoxButton.YesNo);
                if (res == MessageBoxResult.Yes)
                {
                    MenuItem_Save_Click(this, null);
                }

                labObs = new LaboratoryObservable();
                DataContext = labObs;
                com = new Computer();
                Grid_new_Computer.DataContext = com;

                labObs.IsChanged = false;

                ListCollectionView collection_computer = new ListCollectionView(labObs);
                collection_computer.Filter = labObs.Computers;
                comp.ItemsSource = collection_computer;

                ListCollectionView collection_printer = new ListCollectionView(labObs);
                collection_printer.Filter = labObs.Printers;
                print.ItemsSource = collection_printer;

                Binding bd1 = new Binding();
                bd1.Source = print.ItemsSource;
                bd1.Path = new PropertyPath("type");
                TypePrint.SetBinding(TextBlock.TextProperty, bd1);

                Binding bd2 = new Binding();
                bd2.Source = print.ItemsSource;
                bd2.Path = new PropertyPath("year");
                Year.SetBinding(TextBlock.TextProperty, bd2);
            }
            else
            {
                labObs = new LaboratoryObservable();
                DataContext = labObs;
                com = new Computer();
                Grid_new_Computer.DataContext = com;

                labObs.IsChanged = false;

                ListCollectionView collection_computer = new ListCollectionView(labObs);
                collection_computer.Filter = labObs.Computers;
                comp.ItemsSource = collection_computer;

                ListCollectionView collection_printer = new ListCollectionView(labObs);
                collection_printer.Filter = labObs.Printers;
                print.ItemsSource = collection_printer;

                Binding bd1 = new Binding();
                bd1.Source = print.ItemsSource;
                bd1.Path = new PropertyPath("type");
                TypePrint.SetBinding(TextBlock.TextProperty, bd1);

                Binding bd2 = new Binding();
                bd2.Source = print.ItemsSource;
                bd2.Path = new PropertyPath("year");
                Year.SetBinding(TextBlock.TextProperty, bd2);
            }
        }

        private void open()
        {
            OpenFileDialog ofd = new OpenFileDialog();
            if (ofd.ShowDialog() == true)
            {
                try
                {
                    LaboratoryObservable.Load(ofd.FileName, ref labObs);

                    DataContext = labObs;
                    Grid_new_Computer.DataContext = com;

                    ListCollectionView collection_computer = new ListCollectionView(labObs);
                    collection_computer.Filter = labObs.Computers;
                    comp.ItemsSource = collection_computer;

                    ListCollectionView collection_printer = new ListCollectionView(labObs);
                    collection_printer.Filter = labObs.Printers;
                    print.ItemsSource = collection_printer;

                    Binding bd1 = new Binding();
                    bd1.Source = print.ItemsSource;
                    bd1.Path = new PropertyPath("type");
                    TypePrint.SetBinding(TextBlock.TextProperty, bd1);

                    Binding bd2 = new Binding();
                    bd2.Source = print.ItemsSource;
                    bd2.Path = new PropertyPath("year");
                    Year.SetBinding(TextBlock.TextProperty, bd2);
                }
                catch (Exception)
                {
                    MessageBox.Show("Error open file");
                }
            }
        }

        private void MenuItem_Open_Click(object sender, RoutedEventArgs e)
        {
            if (labObs.IsChanged == false)
            {
                open();
            }
            else
            {
                MessageBoxResult res = MessageBox.Show("Сохранить изменения?", "Выбор", MessageBoxButton.YesNo);
                if (res == MessageBoxResult.Yes)
                {
                    MenuItem_Save_Click(this, null);
                }
                else
                {
                    open();
                }
            }
        }

        private void MenuItem_Save_Click(object sender, RoutedEventArgs e)
        {
            SaveFileDialog sfd = new SaveFileDialog();
            if (sfd.ShowDialog() == true)
            {
                try
                {
                    labObs.IsChanged = false;
                    LaboratoryObservable.Save(sfd.SafeFileName, labObs);
                }
                catch (Exception)
                {
                    MessageBox.Show("Error save file");
                }
            }
            labObs.IsChanged = false;
        }

        private void DataWindow_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (labObs.IsChanged == true)
            {
                MessageBoxResult res = MessageBox.Show("Сохранить изменения?", "Выбор", MessageBoxButton.YesNo);
                if (res == MessageBoxResult.Yes)
                {
                    MenuItem_Save_Click(this, null);
                }
            }
        }
    }
}
